@@ -1,47 +1,48 @@
 import numpy as np
 from scipy.stats import t as student
 from typing import Tuple
+from nptyping import NDArray
 
 class AbstractRegression:
 
     _initialized:bool
-    _X:np.ndarray
-    _Y:np.ndarray
+    _X:NDArray
+    _Y:NDArray
     _CI:float
     _FitDim:int
     _Simult:bool
     _NbParms:int
-    _Beta:np.ndarray
-    _BetaFitError:np.ndarray
+    _Beta:NDArray
+    _BetaFitError:NDArray
     
-    _Residuals:np.ndarray
-    _SSE:np.ndarray
-    _MSE:np.ndarray
+    _Residuals:NDArray
+    _SSE:NDArray
+    _MSE:NDArray
 
     @property
-    def X(self) -> np.ndarray:
+    def X(self) -> NDArray:
         """
         The independant variable. 
         """
         return self._X
     
     @X.setter
-    def X(self, value:np.ndarray):
+    def X(self, value:NDArray):
         assert not self._initialized, "Can't change this property after instanciation"
-        assert isinstance(value, np.ndarray), "X must be of type np.ndarray"
+        assert isinstance(value, NDArray), "X must be of type NDArray"
         self._X = value
 
     @property
-    def Y(self) -> np.ndarray:
+    def Y(self) -> NDArray:
         """
         The dependant variable. 
         """
         return self._Y
     
     @Y.setter
-    def Y(self, value:np.ndarray):
+    def Y(self, value:NDArray):
         assert not self._initialized, "Can't change this property after instanciation"
-        assert isinstance(value, np.ndarray), "Y must be of type np.ndarray"
+        assert isinstance(value, NDArray), "Y must be of type NDArray"
         self._Y = value
 
     @property
@@ -118,25 +119,25 @@ class AbstractRegression:
             return student.ppf(1-(1-self.CI)/2,self.DoF)
 
     @property
-    def SSE(self) -> np.ndarray:
+    def SSE(self) -> NDArray:
         """
         The Sum of Squared Errors. 
         """
         return self._SSE
 
     @property
-    def SST(self) -> np.ndarray:
+    def SST(self) -> NDArray:
         """
         The Sum of Squared Totals. 
         """
         return self._SST
 
     @property
-    def MSE(self) -> np.ndarray:
+    def MSE(self) -> NDArray:
         return self._MSE
 
     @property
-    def R2(self) -> np.ndarray:
+    def R2(self) -> NDArray:
         """
         The coefficient of determination. 
         https://en.wikipedia.org/wiki/Coefficient_of_determination
@@ -144,7 +145,7 @@ class AbstractRegression:
         return self._R2
 
     @property
-    def AdjR2(self) -> np.ndarray:
+    def AdjR2(self) -> float:
         """
         The R2 adjusted for the degrees of freedom of the fit. 
         https://en.wikipedia.org/wiki/Coefficient_of_determination
@@ -152,14 +153,14 @@ class AbstractRegression:
         return self._AdjR2
 
     @property
-    def Beta(self) -> np.ndarray:
+    def Beta(self) -> NDArray:
         """
         The fitted parameters. 
         """
         return self._Beta
 
     @property
-    def BetaFitError(self) -> np.ndarray:
+    def BetaFitError(self) -> NDArray:
         """
         The error on the fit parameters. This one is smaller
         and represents where the real estimators likely sits, within the
@@ -185,7 +186,7 @@ class AbstractRegression:
         self._R2 = 1 - self.SSE / self.SST
         self._AdjR2 = 1 - (1-self.R2) * (self.Nb - 1)/self.DoF
 
-    def __init__(self, x:np.ndarray, y:np.ndarray, nbParms:int, fitDim:int=0, confidenceInterval:float=0.95, simult:bool=False):
+    def __init__(self, x:NDArray, y:NDArray, nbParms:int, fitDim:int=0, confidenceInterval:float=0.95, simult:bool=False):
         
         self._initialized = False
 
@@ -219,14 +220,14 @@ class AbstractRegression:
         """
         raise NotImplementedError("This function must be overriden in the child class!")
 
-    def Eval(self, x:np.ndarray) -> np.ndarray:
+    def Eval(self, x:NDArray) -> NDArray:
         """
         Evaluates the fitted function using the values of the
         input array x. 
         """
         raise NotImplementedError("This function must be overriden in the child class!")
 
-    def EvalFitError(self, x:np.ndarray):
+    def EvalFitError(self, x:NDArray) -> NDArray:
         """
         The error on the fit. This one is smaller
         and represents where the real curve likely sits, within the
@@ -234,7 +235,7 @@ class AbstractRegression:
         """
         raise NotImplementedError("This function must be overriden in the child class!")
 
-    def EvalPredictionError(self, x:np.ndarray):
+    def EvalPredictionError(self, x:NDArray) -> NDArray:
         """
         The prediction interval. This one is bigger and represents
         where a new data point is likely to be found, within the 
